@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use v5.16;
 use base 'TAP::Object';
+use TAP::Formatter::GitHubActions::ErrorGroup;
 
 my @ATTR;
 
@@ -38,7 +39,12 @@ sub group {
 
 sub as_sorted_array {
   my ($self) = @_;
-  return map { $self->groups->{$_} } sort keys %{$self->groups};
+
+  return map { $self->groups->{$_} } sort _by_lexical_sortable_numbers keys %{$self->groups};
+}
+
+sub _by_lexical_sortable_numbers {
+  sprintf("%04d", $a) <=> sprintf("%04d", $b);
 }
 
 1;
